@@ -34,7 +34,7 @@ class Hypixel:
 
     def __init__(self, api: str):
         self.api = api
-        self.key = hypixel.get_api_stats(self.api)
+        self.key = await hypixel.get_api_stats(self.api)
         # this could error with InvalidAPIKeyError
         # this acts as a check to see if the API key provided was valid and also will contain the stats of the key
         self.player = Player(self.api)
